@@ -1,7 +1,7 @@
 import networkx as nx
 import networkx.linalg.algebraicconnectivity as alg_connectivity
 
-from features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
+from ...features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
 
 
 class FiedlerVectorCalculator(NodeFeatureCalculator):
@@ -32,5 +32,5 @@ feature_entry = {
 
 
 if __name__ == "__main__":
-    from measure_tests.specific_feature_test import test_specific_feature
+    from ...measure_tests.specific_feature_test import test_specific_feature
     test_specific_feature(FiedlerVectorCalculator, is_max_connected=True)
